#!/bin/bash

# Version
__version__="$Rev: 32524 $"

# Variable to check if an error occurred, since exit() does't work because
# it will exit the session when we call the script with source.
ERROR=0

# Get value of alias cp in case we need to unalias and restore
oldalias=""
alias cp >/dev/null 2>&1

if [ $? == 0 ]
then
    oldalias=$(alias cp | cut -d'=' -f 2-)
    oldalias=${oldalias//\'/}
    unalias cp
fi


function press_key() {
    if [ $ret -eq 0  ]; then
        echo "Press any key to close this windows ..."
        read opt 
    fi
}

# Helper function
function die() {
    echo -e $@
    if [ "x$oldalias" != "x" ]
    then
        alias cp=$oldalias
    fi

    ERROR=1
   
}

# Source MD5
MD5="40a7d58710a289609a297ad4705f5e3a"

# Create directory structure
mkdir -p /opt/intel/icr/sbin                \
         /opt/intel/icr/doc                 \
         /opt/intel/icr/lib/python          \
         /opt/intel/icr/etc &> /dev/null || \
die "Could not create installation directories.\nFinishing."

# Calculate and compare MD5

MY_MD5=$( find src doc clck-config -type f | sort -d | xargs cat | md5sum | \
          sed 's/ .*//g'  )

[ "$MY_MD5" == "$MD5" ] || die "Files are corrupted.\nFinishing."

# Copy python sections
if [ $ERROR == 0 ]
    then
    cp -a src/common src/sections /opt/intel/icr/lib/python &>/dev/null || \
die "Could not copy source files.\nFinishing."

fi

# Copy main executable
if [ $ERROR == 0 ] 
then
    cp -a src/icr_configure.py /opt/intel/icr/sbin/icr_configure &>/dev/null || \
die "Could not copy source files.\nFinishing."
fi

# Copy icrvars script
if [ $ERROR == 0 ] 
then
    cp -a src/icrvars.sh /opt/intel/icr/ &>/dev/null || \
die "Could not copy source files.\nFinishing."
fi

# Copy documentation
if [ $ERROR == 0 ]
then
    cp -a doc/* /opt/intel/icr/doc &>/dev/null || \
    die "Could not copy documentation files.\nFinishing. "
fi

# Copy Intel(R) Cluster Checker files
if [ $ERROR == 0 ]
then
    cp -a clck-config/* /opt/intel/icr/etc &>/dev/null || \
    die "Could not copy configuration files.\nFinishing."
fi

# Copy configuration
if [ $ERROR == 0 ]
then
    cp -a src/icr.ini /opt/intel/icr/etc &>/dev/null || \
    die "Could not copy configuration files.\nFinishing. "
fi

if [ $ERROR == 0 ]
then

    chmod +x /opt/intel/icr/sbin/icr_configure
    chmod a+r /opt/intel/icr/etc/*
    source /opt/intel/icr/icrvars.sh

    # Finish
    echo "Installation finished successfully."

fi

# Restore cp alias if needed
if [ "x$oldalias" != "x" ]
then
    alias cp=$oldalias
fi

