#!/usr/bin/python
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.


""" This module defines the method for CentOS """

# System Modules
import re
import exceptions

# Internal Modules
from common.logger import logger
from common import oslayer 

__version__ = "$Rev: 37362 $"

#############################################################################
#            CentOS   Class Definition                                      #
#############################################################################

class CENTOS(oslayer._OSAL):
    """ Adds support for the CentOS operating system """

    def __init__(self):
        self.version = ''
        oslayer._OSAL.__init__(self, 'CentOS')

    def probe(self):
        """ Probes the existence of the OS in the system by analyzing the
            presence and contents of certain files.
        """
        file_name = '/etc/redhat-release'
        os_pattern = 'CentOS release (\d+(\.\d+)?).*'

        try:
            _file = open(file_name, 'r')
        except exceptions.IOError, exception:
            logger.debug( str(exception))
            raise oslayer.OSNotFound(self.name)

        try:
            file_contents = _file.readline()
        except exceptions.IOError, exception:
            logger.debug( str(exception))
            raise oslayer.OSNotFound(self.name)

        matchs = re.match(os_pattern, file_contents)
        if matchs is None:
            logger.debug ('The expected string was not found in ' + file_name)
            raise oslayer.OSNotFound(self.name)

        self.version = matchs.group(1)
        if self.version is '':
            logger.info("The version for " + self.name + " could not be found")

    def __str__(self):
        return self.name + " " + self.version

if __name__ == "__main__":
    print "This file should not be run alone"
