## OS and Provision detection
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.

""" This module provides functions to execute the detection of OS and
    provisioning systems.
"""

import provisioning
import oslayer
import exceptions
from logger import logger

__version__ = "$Rev: 35275 $"

class DetectionError(Exception):
    """ Base exception for exceptions raised when something fails in the
        detection module.
    """ 

class NoSupportedProvisioning(DetectionError):
    """ Exceptions raised when no provisioning was found in the system
    """ 
    
    def __str__(self):
        return "Could not find a supported Provisioning system"
        

class NoSupportedOS(DetectionError):
    """ Exceptions raised when no supported OS was found in the system
    """ 
    
    def __str__(self):
        return "Could not find a supported operating system"


def detect_os(forced_os=None):
    """ Detect operating system using oslayer module
    """
    opsys = None
    oss_names = ''

    # If non os is forced try to get the os
    if forced_os == None:
        try:
            opsys = oslayer.get_os()
        except oslayer.OSNotFound, ex:
            raise NoSupportedOS(str(ex))
    else:
        logger.warn('Forcing OS to: %s' % forced_os)
        # If an os is forced check if it is registered  or not
        for registered_os in oslayer._supported_operating_systems:
            oss_names = oss_names + " " + str(registered_os).split('.')[2].split('\'>')[0]
            if forced_os == registered_os.__name__:
                opsys = registered_os(True)

        if not opsys:
            logger.warn('Bad OS. Supported OS are: %s' % oss_names)

    if not opsys:
        raise NoSupportedOS()

    return opsys

def detect_provisioning(opsys):
    """ Detect provisioning system using provisioning module
    """

    try:
        prov = provisioning.get_provision()
    except exceptions.Exception:
        raise NoSupportedProvisioning() 

    prov.associate_os(opsys)

    return prov

