#!/usr/bin/env python
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.

import exceptions

__version__ = "$Rev: 35275 $"

class FileParserErrors(exceptions.Exception):
    """ File parser general errors """
    def __init__(self, reason):
        self.reason = reason
    
    def __str__(self):
        return self.reason

class FileError(FileParserErrors):
    """ Error while opening file """
    def __init__(self, message):
        FileParserErrors.__init__(self, message)
        

class ParameterNotFound(FileParserErrors):
    """ The parameter was not found in the file """
    def __init__(self, parameter):
        self.parameter = parameter
        reason = "The parameter \"%s\" was not found in the configuration file"\
                % self.parameter
        FileParserErrors.__init__(self, reason)
        return

    
class SectionNotFound(FileParserErrors):
    """ The section was not found in the file """
    def __init__(self, section):
        
        self.section = section
        reason = "The section \"%s\" was not found in the configuration file"\
                % self.section
        FileParserErrors.__init__(self, reason)
        return


class FileNotFound(FileParserErrors):
    """ The file could not be opened  """
    def __init__(self, filename):

        self.filename = filename
        reason = "The file \"%s\" could not be opened" % self.filename
        FileParserErrors.__init__(self, reason)


class FileWriteError(FileParserErrors):
    """ The file could not be opened  """
    def __init__(self, filename):
        
        self.filename = filename
        reason = "The file \"%s\" could not be written" % self.filename
        FileParserErrors.__init__(self, reason)

class ParsingError(FileParserErrors):
    """ The configuration file could not be parsed """
    def __init__(self, reason):
        FileParserErrors.__init__(self, reason)
        return

class FileParameterParser:
    ''' This class is an interface for the parameter parsing routines 
    
    '''
    def __init__(self, filename):
        self.filename = filename

    def get(self, section, item):
        ''' Should return the value of a parameter '''
        raise exceptions.NotImplementedError()    

    def get_multi(self, section, item):
        ''' Should return the value of a multiple parameter '''
        raise exceptions.NotImplementedError()    

    def add_section (self, section):
        '''Creates a new section in the file'''
        raise exceptions.NotImplementedError()    


    def get_sections(self):
        '''Gets the list of available sections'''
        raise exceptions.NotImplementedError()    

    def return_config_file_contents(self):
        ''' Returns the configuration file representation '''
        raise exceptions.NotImplementedError()    
