#!/usr/bin/env python
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.

import ConfigParser
import fileparameterparser

__version__ = "$Rev: 35275 $"

class IniParameterParser(fileparameterparser.FileParameterParser):
    ''' Module for obtaining the configuration from a .ini file
    '''

    def __init__(self, filename):
        ''' Opens the file with the configuration and reads it 
        '''
        fileparameterparser.FileParameterParser.__init__(self, filename) 
        
        self.parser = ConfigParser.ConfigParser()
        self.parser.optionxform = str

        # If can't parse the file raise Paring Error exception
        try:
            filed = self.parser.read(self.filename)
        except ConfigParser.ParsingError, ex:
            raise fileparameterparser.ParsingError(str(ex))
        
        self.config_updated = False
            
        if not filed:
            #Could not read the file
            raise fileparameterparser.FileNotFound(self.filename)




    def get(self, section, item):
        '''Gets a parameter available in a known section'''
        value = None
        try:
            value = self.parser.get(section, item)
        except ConfigParser.NoSectionError:
            raise fileparameterparser.SectionNotFound(section)
        except ConfigParser.NoOptionError:
            raise fileparameterparser.ParameterNotFound(item)
        return value

    def get_multi(self, section, item):
        '''Gets a parameter available in a known section'''
        # Initialize variables
        values = list()
        values_str = str()
        result = list()
        value_splitted = list()
        value_dict = dict()

        # Retrieve a multiline parameter
        try:
            values_str = self.parser.get(section, item)
        except ConfigParser.NoSectionError:
            raise fileparameterparser.SectionNotFound(section)
        except ConfigParser.NoOptionError:
            raise fileparameterparser.ParameterNotFound(item)

        # Split the string to obtain all values
        values = values_str.split('\n')

        # Multiline parameter are returned as a list of dictionaries
        # Dictionary e.g.: 
        # dict_1 = {'name':<value1>,<var2>:<value2>,<varN>:<valueN>}
        # Value returned e.g.:
        # result = [dict_1,dict_2,dict_N]

        # Remove all empty values and create the dictionary
        for value in values:
            # Remove new line character
            value = value.strip()

            if not value == "":
                # Clean var
                value_dict = {}

                # Set the value name as the first option found
                value_splitted = value.split(':')

                # Set the first value to name key
                value_dict['name'] = value_splitted[0]
                
                # If there are more options, split them by '='
                value_splitted = value_splitted[1:]

                for evalue in value_splitted:
                    if '=' not in evalue:
                        continue
                    varname, varvalue = evalue.split('=', 1)
                    value_dict[varname.strip()] = varvalue.strip()

                result.append(value_dict)

        # Return the list with all the dictionaries
        return result

    def get_sections(self):
        '''Gets the list of available sections'''

        return self.parser.sections()

    def add_section (self, section):
        '''Creates a new section in the file'''
        try:
            self.parser.add_section(section)
        except ConfigParser.DuplicateSectionError:
            # Ignore this error
            pass

    def return_config_file_contents(self):
        """ Returns the configuration file representation """
        try:
            file_descriptor = open (self.filename)
        except IOError, ex:
            msg = "Error opening file %s: %s" % (self.filename, str(ex))
            raise fileparameterparser.FileError(msg)

        try:
            file_contents = file_descriptor.readlines()
        except IOError, ex:
            msg = "Error reading file %s: %s" % (self.filename, str(ex))
            raise fileparameterparser.FileError(msg)

        file_descriptor.close()
        
        return file_contents

if __name__ == "__main__":
    print "This file should not be run alone"
