#!/usr/bin/env python
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.


import os
import exceptions
import sys 
from common.logger import logger

__version__ = "$Rev: 35275 $"

SECTIONS_DIR="sections"


def import_recipe_sections():

    # get current directory from section path and split the directories
    split_path = __file__.split(os.path.sep)

    # assume we get DIR/common/sectionloader.py, we need DIR/SECTIONS_DIR
    try:
        path = os.path.sep.join(split_path[:-2] + [SECTIONS_DIR] )
    except Exception, ex:
        logger.debug(ex)
        logger.error('Error getting sections directory from ' + \
            os.path.sep.join(path))

    dir_list = os.listdir(path)

    section_dict={}

    imported_sections = []
    section_names = []

    for file in dir_list:
        if file.endswith(".py") and file != "__init__.py":
            name = file.replace(".py","")
            
            try:
                __import__("sections", globals(), locals(), [name] )
                section_names.append(name) 
            except exceptions.Exception, ex:
                print "Error importing section %s: %s" % (name, ex)


    for sect_name in section_names:
        try:
            section_name = sys.modules["sections." + sect_name].\
                SECTION_PROPERTIES['name']
            
            section_dict[section_name] = sys.modules["sections." + sect_name].\
                SECTION_PROPERTIES['class'] 
            logger.debug("Loaded section %s" % (section_name))

        except exceptions.AttributeError:
            logger.warn("The section %s is invalid, check that" % (sect_name) +\
            " SECTION_PROPERTIES is correctly configured" )

    return section_dict



