#!/usr/bin/python
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.

import exceptions

__version__ = "$Rev: 35275 $"

class UserInterfaceErrors(exceptions.Exception):
    """ Base class for User Interface exceptions """
    
    def __init__(self, reason):
        exceptions.Exception.__init__(self)
        self.reason = reason

    def __str__(self):
        return self.reason

class InvalidParameters(UserInterfaceErrors):
    """ The parameters inserted by the user are invalid """

    def __init__(self, reason):
        UserInterfaceErrors.__init__(self, reason)
        

    
class ParameterNotFound(UserInterfaceErrors):
    """ The parameter requested by the user is invalid """

    def __init__(self, parameter_name):
        reason = "Parameter %s not configured in user interface" % \
            parameter_name
        UserInterfaceErrors.__init__(self, reason)


class SectionNotFound(UserInterfaceErrors):
    """ The section requested by the user is invalid """

    def __init__(self, section_name):
        reason = "Section %s not available in user interface" % \
            section_name
        UserInterfaceErrors.__init__(self, reason)
        

class UserInterfaceExit(UserInterfaceErrors):
    """ The user requested that the program terminates """

    def __init__(self):
        reason = "Program terminated by User"
        UserInterfaceErrors.__init__(self, reason)

    
class UserInterface:
    ''' Abstraction of user interfaces  '''

    def __init__(self, argv, parameer_list, tool_name, tool_description, 
        tool_version):
        ''' Initializes the user interface'''
        raise exceptions.NotImplementedError()

    
    def run(self):
        ''' Executes the User Interface parameter gathering, if
        it is a GUI, the GUI should start the interface and
        set up all the redirection of logging.'''
        raise exceptions.NotImplementedError()

    def get_parameter(self, section, item):
        ''' Should return the value of a parameter '''
        raise exceptions.NotImplementedError()

    def help(self):
        ''' Displays the help to the user '''
        raise exceptions.NotImplementedError()

    def exit(self):
        ''' Exits from the user interface '''
        raise exceptions.NotImplementedError()

    def get_parameter_list(self, section):
        ''' Obtained the list of defined parameters '''
        raise exceptions.NotImplementedError()

    def get_sections (self):
        ''' Gets the sections that has values in their parameters '''
        raise exceptions.NotImplementedError()

