#!/bin/bash
# Copyright 2009-2011 Intel Corporation All Rights Reserved.
#
# The source code contained or described herein and all documents
# related to the source code ("Material") are owned by Intel
# Corporation or its suppliers or licensors. Title to the Material
# remains with Intel Corporation or its suppliers and licensors. The
# Material may contain trade secrets and proprietary and confidential
# information of Intel Corporation and its suppliers and licensors,
# and is protected by worldwide copyright and trade secret laws and
# treaty provisions. No part of the Material may be used, copied,
# reproduced, modified, published, uploaded, posted, transmitted,
# distributed, or disclosed in any way without Intel's prior express
# written permission.
#
# No license under any patent, copyright, trade secret or other
# intellectual property right is granted to or conferred upon you by
# disclosure or delivery of the Materials, either expressly, by
# implication, inducement, estoppel or otherwise. Any license under
# such intellectual property rights must be express and approved by
# Intel in writing.
#
# Unless otherwise agreed by Intel in writing, you may not remove or
# alter this notice or any other notice embedded in Materials by Intel
# or Intel's suppliers or licensors in any way.

__version__="$Rev: 32524 $"

function grep_check 
{
	text_to_check=$1
	file_to_check=$2
	REST=$(grep "$text_to_check" $file_to_check)
	return $?
}
function set_value
{
	exist_value=$1
	parameter=$2
	file_to_change=$3
	
	if [ $exist_value -eq 1 ]
		then 
			echo "#Line added by Automata ICR Recipe" >> $file_to_change
			echo "$parameter" >> $file_to_change
		fi
}

MODPROBEFILE="/etc/modprobe.d/modprobe.conf"
DAT_CONF="/etc/rdma/dat.conf"

if [ ! -f "$DAT_CONF" ]
then
    if [ -f "/etc/ofed/dat.conf" ]
    then
        ln -s "/etc/ofed/dat.conf" "$DAT_CONF"

    elif [ -f "/etc/ofed/compat-dapl/dat.conf" ]
    then
        ln -s "/etc/ofed/compat-dapl/dat.conf" "$DAT_CONF"

    else
        touch "$DAT_CONF"
    fi

fi

REST=$(ibstat -l |grep "mlx4_0")

if [ $? -eq 0 ]
 then
	echo -e "Setting DAT.conf configuration ConnectX Cards"
	echo "#Line added by Automate ICR Recipe" > $DAT_CONF
	echo "OpenIB-mlx4_0-1 u1.2 nonthreadsafe default libdaplscm.so.1 dapl.1.2 \"mlx4_0 1\" \"\"" >> $DAT_CONF
	echo "ofa-v2-mlx4_0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 \"mlx4_0 1\" \"\"" >> $DAT_CONF
 fi

echo -e "Setting DAT.conf configuration for Infinihost Card"
echo "#Line added by Automate ICR Recipe" >> $DAT_CONF
echo "OpenIB-cma u1.2 nonthreadsafe default libdaplcma.so.1 dapl.1.2 \"ib0 0\" \"\"" >> $DAT_CONF
echo "ofa-v2-ib0 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 \"ib0 0\" \"\"" >> $DAT_CONF

echo -e "Done DAT.conf configuration"
echo -e "Updating the Libraries database"
ln -fs /usr/lib64/libdat.so.1 /usr/lib64/libdat.so
ln -fs /usr/lib64/libdat2.so.2 /usr/lib64/libdat2.so
ldconfig

declare MSI
MSI=$(cat /proc/interrupts | grep "mlx4_core" | grep "async" | grep -o "PCI-MSI-X")
if [ "$MSI" = "PCI-MSI-X" ];
	then
	echo -e "Setting the MSI-X configuration IB ConnectX Cards"
	grep_check "mlx4_core msi_x=1" $MODPROBEFILE
	set_value $? "options mlx4_core msi_x=1" $MODPROBEFILE
	fi
	
MSI=$(cat /proc/interrupts | grep "mthca" |grep "async" | grep -o "PCI-MSI-X")
if [ "$MSI" = "PCI-MSI-X" ]
	then
	echo -e "Setting the MSI-X configuration IB Infinihost Cards"
	grep_check "ib_mthca msi_x=1" $MODPROBEFILE
	set_value $? "options ib_mthca msi_x=1" $MODPROBEFILE
	fi
echo -e "Setting the OFED BKM configuration"
grep_check "paths_per_dest=" $MODPROBEFILE
set_value $? "options ib_sa paths_per_dest=0x7f" $MODPROBEFILE

grep_check "cma_response_timeout=" $MODPROBEFILE
set_value $? "options rdma_cm cma_response_timeout=24" $MODPROBEFILE

grep_check "send_queue_size=128" $MODPROBEFILE
set_value $? "options ib_ipoib send_queue_size=128" $MODPROBEFILE

grep_check "recv_queue_size=128" $MODPROBEFILE
set_value $? "options ib_ipoib recv_queue_size=128" $MODPROBEFILE
echo -e "Done the OFED BKM configuration"
